pub trait IntoRequestExt {
// Provided method
fn into_request(self) -> Request<Self>
where Self: Sized { ... }
}Expand description
Helper trait for converting any value into a tonic::Request<T>.
Implemented for every T via the blanket impl below. Per-domain method
impls use payload.into_request() instead of
tonic::Request::new(payload).
Provided Methods
fn into_request(self) -> Request<Self>where
Self: Sized,
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".